==> seedsui-react-5.6.70.tgz: package/lib/Layout/Main/TopContainer.js <==
var _excluded = ["children", "caption", "type"];
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import locale from "./../../locale";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var TopContainer = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var children = _ref.children,
    caption = _ref.caption,
    type = _ref.type,
    props = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  return /*#__PURE__*/_jsx("div", {
    ref: rootRef,
    className: "SID-Dragrefresh-TopContainer layout-main-pull-push",
    children: /*#__PURE__*/_jsxs("div", {
      className: "layout-main-pull-push-box",
      children: [/*#__PURE__*/_jsx("div", {
        className: "layout-main-pull-push-icon"
      }), /*#__PURE__*/_jsx("div", {
        className: "layout-main-pull-push-caption",
        children: locale('下拉可以刷新', 'pull_down')
      })]
    })
  });
});
export default TopContainer;

==> seedsui-react-5.7.84.tgz: package/lib/Layout/Main/TopContainer.js <==
var _excluded = ["children", "caption", "type"];
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef, useRef, useImperativeHandle } from 'react';
import locale from "./../../locale";
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var TopContainer = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var children = _ref.children,
    caption = _ref.caption,
    type = _ref.type,
    props = _objectWithoutProperties(_ref, _excluded);
  var rootRef = useRef(null);
  useImperativeHandle(ref, function () {
    return rootRef.current;
  });
  return /*#__PURE__*/_jsx("div", {
    ref: rootRef,
    className: "SID-Dragrefresh-TopContainer layout-main-pull-push",
    children: /*#__PURE__*/_jsxs("div", {
      className: "layout-main-pull-push-wrapper",
      children: [/*#__PURE__*/_jsx("div", {
        className: "layout-main-pull-push-icon"
      }), /*#__PURE__*/_jsx("div", {
        className: "layout-main-pull-push-caption",
        children: locale('下拉可以刷新', 'pull_down')
      })]
    })
  });
});
export default TopContainer;
